@@ -4,15 +4,16 @@
 # @Author: ZeFeng Zhu
 # @Last Modified: 2020-09-27 03:18:19 pm
 # @Copyright (c) 2020 MinghuiGroup, Soochow University
-from asyncio import sleep as asyncio_sleep, Queue
-from queue import Queue
+from asyncio import sleep as asyncio_sleep
 import databases
 import orm
 import sqlalchemy
-from sqlite3 import OperationalError
+from sqlite3 import OperationalError, InterfaceError
 from unsync import unsync
 from typing import Dict, Iterable
 from pdb_profiling.log import Abclog
+from random import uniform
+# from queue import Queue
 
 
 class SqliteDB(Abclog):
@@ -36,32 +37,34 @@ class SqliteDB(Abclog):
         self.engine.dispose()
 
     def sync_insert(self, table, values: Iterable[Dict], prefix_with: str = "OR IGNORE"):
-        self.engine.execute(
-            table.__table__.insert().prefix_with(prefix_with),
-            values)
+        try:
+            self.engine.execute(
+                table.__table__.insert().prefix_with(prefix_with),
+                values)
+        except InterfaceError as e:
+            self.logger.error(f"{e}\n{values}")
+            raise e
 
     '''
     @unsync
     async def async_insert_queue(self, table, values: Iterable[Dict], prefix_with: str = "OR IGNORE", insert_sleep: float = 30.5):
         self.queue.put_nowait(self.database.execute(table.__table__.insert().values(values).prefix_with(prefix_with)))
         now_task = self.queue.get_nowait()
-        while True:
-            try:
-                await now_task
-                self.queue.task_done()
-                break
-            except OperationalError as e:
-                self.logger.error(f"{e}, sleep {insert_sleep}s and try again")
-                await asyncio_sleep(insert_sleep)
+        await now_task
+        self.queue.task_done()
     '''
 
     @unsync
-    async def async_insert(self, table, values: Iterable[Dict], prefix_with: str = "OR IGNORE", insert_sleep:float=30.5):
+    async def async_insert(self, table, values: Iterable[Dict], prefix_with: str = "OR IGNORE", insert_sleep_range=(10,30)):
         while True:
             try:
                 query = table.__table__.insert().values(values).prefix_with(prefix_with)
                 await self.database.execute(query)
                 break
             except OperationalError as e:
-                self.logger.error(f"{e}, sleep {insert_sleep}s and try again")
+                insert_sleep = uniform(*insert_sleep_range)
+                self.logger.error(f"OperationalError: sleep {insert_sleep}s and try again")
                 await asyncio_sleep(insert_sleep)
+            except InterfaceError as e:
+                self.logger.error(f"{e}\n{values}")
+                raise e
